/**
 * Highwire Article access indicator
 *
 * Copyright (c) 2010-2011 Board of Trustees, Leland Stanford Jr. University
 * This software is open-source licensed under the GNU Public License Version 2 or later
 * The full license is available in the LICENSE.TXT file at the root of this repository
 */
(function ($) {
  // Store our function as a property of Drupal.behaviors.
  Drupal.behaviors.highwire_access_indicator = {
    attach: function (context, settings) {
      var items = [];

      // The ajax call seems to error intermittently on the first run through.
      // During subsequent times that drupal.behaviors is loaded, the
      // context is no longer the document object, which was causing it to fail
      // the lookup.
      $access_icons = $('span.highwire-citation-access-check, span.highwire-citation-pdf-download');

      $access_icons.each(function() {
        var itemdata = {
          pisa_id: $(this).closest('[data-pisa-id]').data('pisa-id'),
          apath: $(this).closest('[data-apath]').data('apath'),
          view: $(this).data('request-view'),
        };
        items.push(itemdata);
      });
      if (items.length > 0) {
        $.ajax({
          url: '/highwire/articlecitation/ac',
          type: 'POST',
          data: {'items' : items},
          success: function(data) {
            $access_icons.each(function(index){
              var elem = $(this);
              var pisa_id = $(this).closest('[data-pisa-id]').data('pisa-id');
              var apath   = $(this).closest('[data-apath]').data('apath');
              var view = elem.data('request-view');
              // The key can be defined using other elements, but we should
              // always know a pisa_id and a view.
              if (pisa_id) {
                var ac_key = pisa_id + '||' + view;
              }
              else if (apath) {
                 var ac_key = apath + '||' + view;
               }

              if (data[ac_key]['access'][view] != undefined && data[ac_key]['access'][view] == true) {
                if (elem.hasClass('highwire-citation-access-check')) {
                  elem.children('.highwire-access-icon-user-access').show();
                  elem.children('.highwire-access-icon-no-access').hide();
                }
                else if (elem.hasClass('highwire-citation-pdf-download')) {
                  elem.show();
                }
              }
              else {
                elem.children('.highwire-access-icon-no-access').show();
                elem.children('.highwire-access-icon-user-access').hide();
              }
            });
          },
        });
      }
    }
  };
}(jQuery));
